.. MEDS-TAB documentation master file, created by
   sphinx-quickstart on Mon Jun  3 20:41:52 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MEDS-TAB's documentation!
====================================
.. image:: https://readthedocs.org/projects/meds-tabular-automl/badge/?version=latest
    :target: https://meds-tabular-automl.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   overview
   installation
   usage
   api
   license
